# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_hydra_client
from ory_hydra_client.models.o_auth2_token_introspection import OAuth2TokenIntrospection  # noqa: E501
from ory_hydra_client.rest import ApiException


class TestOAuth2TokenIntrospection(unittest.TestCase):
    """OAuth2TokenIntrospection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOAuth2TokenIntrospection(self):
        """Test OAuth2TokenIntrospection"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ory_hydra_client.models.o_auth2_token_introspection.OAuth2TokenIntrospection()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
